==> openai_search-2.0.14.tar.gz: openai_search/src/Plugin/Block/AiChatBlock.php <==
<?php

namespace Drupal\openai_search\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Routing\RouteMatchInterface;

/**
 * Provides an AI Chat block with file upload.
 *
 * @Block(
 *   id = "openai_chat_block",
 *   admin_label = @Translation("AI Chat with File Upload"),
 *   category = @Translation("OpenAI Search")
 * )
 */
class AiChatBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The current route match.
   *
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  protected $routeMatch;

  /**
   * Constructs a new AiChatBlock instance.
   *
   * @param array $configuration
   *   The plugin configuration.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *   The current route match.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, RouteMatchInterface $route_match) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->routeMatch = $route_match;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_route_match')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $node = $this->routeMatch->getParameter('node');
    $node_id = $node ? $node->id() : null;

    if (!$node_id || $node->bundle() !== 'private_gpts') {
      return [
        '#markup' => $this->t('This block can only be used on private_gpts nodes.'),
      ];
    }
    
    return [
      '#theme' => 'openai_chat',
      '#attached' => [
        'library' => [
          'openai_search/chat-interface',
        ],
        'drupalSettings' => [
          'openai_search' => [
            'restful_url' => '/api/openai-search',
            'ai_url' => $node_id,
            'node_type' => 'private_gpts',
            'session_id' => session_id(),
            'use_javascript' => 1,
            'current_node_id' => $node_id,
          ],
        ],
      ],
    ];
  }
}

==> openai_search-2.0.23.tar.gz: openai_search/src/Plugin/Block/AiChatBlock.php <==
<?php

namespace Drupal\openai_search\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Routing\RouteMatchInterface;

/**
 * Provides an AI Chat block with file upload.
 *
 * @Block(
 *   id = "openai_chat_block",
 *   admin_label = @Translation("AI Chat with File Upload"),
 *   category = @Translation("OpenAI Search")
 * )
 */
class AiChatBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The current route match.
   *
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  protected $routeMatch;

  /**
   * Constructs a new AiChatBlock instance.
   *
   * @param array $configuration
   *   The plugin configuration.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *   The current route match.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, RouteMatchInterface $route_match) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->routeMatch = $route_match;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_route_match')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $node = $this->routeMatch->getParameter('node');
    $node_id = $node ? $node->id() : null;

    if (!$node_id || $node->bundle() !== 'private_gpts') {
      return [
        '#markup' => $this->t('This block can only be used on private_gpts nodes.'),
      ];
    }
    $username = NULL;
    $author = $node->getOwner();
    $username = $author ? $author->getAccountName() : NULL;
    $restful_url = \Drupal::config('openai_search.settings')->get('restful_url');
    $ai_url = $restful_url . '/' . $username . '_' . 'node' . '_' . $node_id;
    return [
      '#theme' => 'openai_chat',
      '#attached' => [
        'library' => [
          'openai_search/chat-interface',
        ],
        'drupalSettings' => [
          'openai_search' => [
            'restful_url' => $restful_url,
            'ai_url' => $ai_url,
            'node_type' => 'private_gpts',
            'session_id' => session_id(),
            'use_javascript' => 1,
            'current_node_id' => $node_id,
          ],
        ],
      ],
    ];
  }
}
